@@ -87,7 +87,7 @@ class Pg:
         keys = list(opts.keys())
         limit = f"{keys[0]} = $1"
 
-        contents = await self.pool.fetch(f'SELECT * FROM {self.table} ORDER BY {target} {opt} {limit}', *opt.values())
+        contents = await self.pool.fetch(f'SELECT * FROM {self.table} ORDER BY {target} {opt} {limit}', *opts.values())
         return contents
 
 
